@@ -8,6 +8,7 @@
 */
 
 #include "xcb_framebuffer.h"
+#include "krfb_fb_xcb_debug.h"
 
 #include <xcb/xcb.h>
 #include <xcb/xproto.h>
@@ -23,7 +24,6 @@
 #include <QGuiApplication>
 #include <QScreen>
 #include <QAbstractNativeEventFilter>
-#include <QDebug>
 
 
 class KrfbXCBEventFilter: public QAbstractNativeEventFilter
@@ -68,7 +68,7 @@ KrfbXCBEventFilter::KrfbXCBEventFilter(XCBFrameBuffer *owner):
         }
 
 #ifdef _DEBUG
-        qDebug() << "xcb framebuffer: XDamage extension version:" <<
+        qCDebug(KRFB_FB_XCB) << "xcb framebuffer: XDamage extension version:" <<
                xdamage_version->major_version << "." << xdamage_version->minor_version;
 #endif
 
@@ -105,7 +105,7 @@ bool KrfbXCBEventFilter::nativeEventFilter(const QByteArray &eventType,
     if (xdamageBaseEvent == 0) return false;  // no xdamage extension
 
     if (eventType == "xcb_generic_event_t") {
-        xcb_generic_event_t* ev = static_cast<xcb_generic_event_t *>(message);
+        auto ev = static_cast<xcb_generic_event_t *>(message);
         if ((ev->response_type & 0x7F) == (xdamageBaseEvent + XCB_DAMAGE_NOTIFY)) {
             // this is xdamage notification
             this->fb_owner->handleXDamageNotify(ev);
@@ -166,7 +166,8 @@ XCBFrameBuffer::XCBFrameBuffer(WId winid, QObject *parent):
         qreal scaleFactor = primaryScreen->devicePixelRatio();
         d->area = { primaryScreen->geometry().topLeft() * scaleFactor,
                     primaryScreen->geometry().bottomRight() * scaleFactor };
-        qDebug() << "xcb framebuffer: Primary screen: " << primaryScreen->name()
+
+        qCDebug(KRFB_FB_XCB) << "xcb framebuffer: Primary screen: " << primaryScreen->name()
                  << ", geometry: " << primaryScreen->geometry()
                  << ", device scaling: " << scaleFactor
                  << ", native size: " << d->area
@@ -186,7 +187,7 @@ XCBFrameBuffer::XCBFrameBuffer(WId winid, QObject *parent):
                                         XCB_IMAGE_FORMAT_Z_PIXMAP);
     if (d->framebufferImage) {
 #ifdef _DEBUG
-        qDebug() << "xcb framebuffer: Got primary screen image. bpp: " << d->framebufferImage->bpp
+        qCDebug(KRFB_FB_XCB) << "xcb framebuffer: Got primary screen image. bpp: " << d->framebufferImage->bpp
                  << ", size (" << d->framebufferImage->width << d->framebufferImage->height << ")"
                  << ", depth: " << d->framebufferImage->depth
                  << ", padded width: " << d->framebufferImage->stride;
@@ -214,15 +215,15 @@ XCBFrameBuffer::XCBFrameBuffer(WId winid, QObject *parent):
                     nullptr);                   // data = 0
         if (d->updateTile) {
 #ifdef _DEBUG
-            qDebug() << "xcb framebuffer: Successfully created new empty image in native format";
-            qDebug() << "    size: " << d->updateTile->width << "x" << d->updateTile->height
-                     << "(stride: " << d->updateTile->stride << ")";
-            qDebug() << "    bpp, depth:  " << d->updateTile->bpp << d->updateTile->depth; // 32, 24
-            qDebug() << "    addr of base, data:  " << d->updateTile->base << (void *)d->updateTile->data;
-            qDebug() << "    size:  " << d->updateTile->size;
-            qDebug() << "    image byte order = " << d->updateTile->byte_order;  // == 0 .._LSB_FIRST
-            qDebug() << "    image bit order = " << d->updateTile->bit_order;    // == 1 .._MSB_FIRST
-            qDebug() << "    image plane_mask = " << d->updateTile->plane_mask;  // == 16777215 == 0x00FFFFFF
+            qCDebug(KRFB_FB_XCB) << "xcb framebuffer: Successfully created new empty image in native format"
+                << "\n    size: " << d->updateTile->width << "x" << d->updateTile->height
+                    << "(stride: " << d->updateTile->stride << ")"
+                << "\n    bpp, depth:  " << d->updateTile->bpp << d->updateTile->depth // 32, 24
+                << "\n    addr of base, data:  " << d->updateTile->base << (void *)d->updateTile->data
+                << "\n    size:  " << d->updateTile->size
+                << "\n    image byte order = " << d->updateTile->byte_order   // == 0 .._LSB_FIRST
+                << "\n    image bit order = " << d->updateTile->bit_order     // == 1 .._MSB_FIRST
+                << "\n    image plane_mask = " << d->updateTile->plane_mask;  // == 16777215 == 0x00FFFFFF
 #endif
 
             // allocate shared memory block only once, make its size large enough
@@ -240,7 +241,7 @@ XCBFrameBuffer::XCBFrameBuffer(WId winid, QObject *parent):
             xcb_shm_attach(QX11Info::connection(), d->shminfo.shmseg, d->shminfo.shmid, 0);
 
 #ifdef _DEBUG
-            qDebug() << "    shm id: " << d->shminfo.shmseg << ", addr: " << (void *)d->shminfo.shmaddr;
+            qCDebug(KRFB_FB_XCB) << "    shm id: " << d->shminfo.shmseg << ", addr: " << (void *)d->shminfo.shmaddr;
 #endif
 
             // will return 1 on success (yes!)
@@ -276,7 +277,7 @@ XCBFrameBuffer::XCBFrameBuffer(WId winid, QObject *parent):
     }
 
 #ifdef _DEBUG
-    qDebug() << "xcb framebuffer: XCBFrameBuffer(), xshm base event = " << d->x11EvtFilter->xshmBaseEvent
+    qCDebug(KRFB_FB_XCB) << "xcb framebuffer: XCBFrameBuffer(), xshm base event = " << d->x11EvtFilter->xshmBaseEvent
              << ", xshm base error = " << d->x11EvtFilter->xdamageBaseError
              << ", xdamage base event = " << d->x11EvtFilter->xdamageBaseEvent
              << ", xdamage base error = " << d->x11EvtFilter->xdamageBaseError;
@@ -423,10 +424,12 @@ void XCBFrameBuffer::getServerFormat(rfbPixelFormat &format) {
         format.blueMax  = root_visualtype->blue_mask >> format.blueShift;
 
 #ifdef _DEBUG
-        qDebug() << "    Calculated redShift   =" << (int)format.redShift;
-        qDebug() << "    Calculated greenShift =" << (int)format.greenShift;
-        qDebug() << "    Calculated blueShift  =" << (int)format.blueShift;
-        qDebug(     "    Calculated max values: R%d G%d B%d",
+        qCDebug(KRFB_FB_XCB,
+            "    Calculated redShift   = %d\n"
+            "    Calculated greenShift = %d\n"
+            "    Calculated blueShift  = %d\n"
+            "    Calculated max values: R%d G%d B%d",
+               format.redShift, format.greenShift, format.blueShift
                format.redMax, format.greenMax, format.blueMax);
 #endif
     } else {
@@ -480,10 +483,10 @@ void XCBFrameBuffer::cleanupRects() {
         QRect ri = r.intersected(d->area);
 
         if (tiles.size() > 0) {
-            for (int i = 0; i < tiles.size(); i++) {
-                // if current rect has intersection with tiles[i], unite them
-                if (ri.intersects(tiles[i])) {
-                    tiles[i] |= ri;
+            for (auto &tile : tiles) {
+                // if current rect has intersection with tile, unite them
+                if (ri.intersects(tile)) {
+                    tile |= ri;
                     inserted = true;
                     break;
                 }
@@ -501,25 +504,25 @@ void XCBFrameBuffer::cleanupRects() {
 
     // increase all rectangles size by 30 pixels each side.
     // limit coordinates to primary monitor boundaries.
-    for (int i = 0; i < tiles.size(); i++) {
-        tiles[i].adjust(-30, -30, 30, 30);
-        if (tiles[i].top() < d->area.top()) {
-            tiles[i].setTop(d->area.top());
+    for (auto &tile : tiles) {
+        tile.adjust(-30, -30, 30, 30);
+        if (tile.top() < d->area.top()) {
+            tile.setTop(d->area.top());
         }
-        if (tiles[i].bottom() > d->area.bottom()) {
-            tiles[i].setBottom(d->area.bottom());
+        if (tile.bottom() > d->area.bottom()) {
+            tile.setBottom(d->area.bottom());
         }
         //
-        if (tiles[i].left() < d->area.left()) {
-            tiles[i].setLeft(d->area.left());
+        if (tile.left() < d->area.left()) {
+            tile.setLeft(d->area.left());
         }
-        if (tiles[i].right() > d->area.right()) {
-            tiles[i].setRight(d->area.right());
+        if (tile.right() > d->area.right()) {
+            tile.setRight(d->area.right());
         }
         // move update rects so that they are positioned relative to
         //   framebuffer image, not whole screen
-        tiles[i].moveTo(tiles[i].left() - d->area.left(),
-                        tiles[i].top() - d->area.top());
+        tile.moveTo(tile.left() - d->area.left(),
+                    tile.top() - d->area.top());
     }
 }
 
@@ -679,7 +682,7 @@ void XCBFrameBuffer::stopMonitor() {
 
 
 void XCBFrameBuffer::handleXDamageNotify(xcb_generic_event_t *xevent) {
-    xcb_damage_notify_event_t *xdevt = (xcb_damage_notify_event_t *)xevent;
+    auto xdevt = (xcb_damage_notify_event_t *)xevent;
 
     QRect r((int)xdevt->area.x,     (int)xdevt->area.y,
             (int)xdevt->area.width, (int)xdevt->area.height);
