@@ -23,7 +23,7 @@
 
 #include "krfbprivate_export.h"
 
-#include <QtCore/QVariantList>
+#include <QVariantList>
 #include <QWidget>
 
 
@@ -35,7 +35,7 @@ class KRFBPRIVATE_EXPORT FrameBufferPlugin : public QObject
 
 public:
     FrameBufferPlugin(QObject *parent, const QVariantList &args);
-    virtual ~FrameBufferPlugin();
+    ~FrameBufferPlugin() override;
 
     virtual FrameBuffer *frameBuffer(WId id) = 0;
 };
